==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebSummaryTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryResultDescriptionMetadata } from "./WebSummaryResultDescriptionMetadata";
import { WebSummaryTemplateContextDescription } from "./WebSummaryTemplateContextDescription";
/**
 * @hidden
 */
export let WebSummaryTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryTemplateContextDescriptionMetadata.a == null) {
                WebSummaryTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryTemplateContextDescriptionMetadata.c(WebSummaryTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebSummaryTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSummaryTemplateContextDescriptionMetadata.a);
            WebSummaryResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "Array:WebSummaryResultDescription:SummaryResult");
        }
        static d(a) {
            WebSummaryTemplateContextDescriptionMetadata.b(a);
            a.aa("WebSummaryTemplateContext", () => new WebSummaryTemplateContextDescription());
            a.z("WebSummaryTemplateContext", WebSummaryTemplateContextDescriptionMetadata.a);
        }
    }
    WebSummaryTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryTemplateContextDescriptionMetadata, 'WebSummaryTemplateContextDescriptionMetadata');
    WebSummaryTemplateContextDescriptionMetadata.a = null;
    return WebSummaryTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSummaryTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryResultDescriptionMetadata } from "./WebSummaryResultDescriptionMetadata";
import { WebSummaryTemplateContextDescription } from "./WebSummaryTemplateContextDescription";
/**
 * @hidden
 */
export let WebSummaryTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryTemplateContextDescriptionMetadata.a == null) {
                WebSummaryTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryTemplateContextDescriptionMetadata.c(WebSummaryTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebSummaryTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSummaryTemplateContextDescriptionMetadata.a);
            WebSummaryResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "Array:WebSummaryResultDescription:SummaryResult");
        }
        static d(a) {
            WebSummaryTemplateContextDescriptionMetadata.b(a);
            a.ac("WebSummaryTemplateContext", () => new WebSummaryTemplateContextDescription());
            a.ab("WebSummaryTemplateContext", WebSummaryTemplateContextDescriptionMetadata.a);
        }
    }
    WebSummaryTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryTemplateContextDescriptionMetadata, 'WebSummaryTemplateContextDescriptionMetadata');
    WebSummaryTemplateContextDescriptionMetadata.a = null;
    return WebSummaryTemplateContextDescriptionMetadata;
})();
